import {Component, EventEmitter, Input, Output} from '@angular/core';
import {MatCardModule} from "@angular/material/card";
import {MatButton} from "@angular/material/button";
import {catchError, Observable, tap} from "rxjs";
import {DataSpinnerComponent} from "@component/common/data-spinner/data-spinner.component";

@Component({
  selector: 'app-configuration-card',
  imports: [
    MatCardModule,
    MatButton,
    DataSpinnerComponent
  ],
  templateUrl: './configuration-card.component.html'
})
export class ConfigurationCardComponent {
  @Input() title: string = '';
  @Input() isSaveEnabled: boolean = false;
  @Input() saveFunction!: () => Observable<any>;
  @Output() onSaveFunction = new EventEmitter<any>();

  protected isLoading: boolean = false;

  onSave(): void {
    this.isLoading = true;

    const result = this.saveFunction().pipe(catchError(err => {
        this.isLoading = false;
        throw err;
      }),
      tap(_ => {
        this.isLoading = false;
      }));

    this.onSaveFunction.emit(result);
  }
}
